package de.w665.pr.statemachine.trafficlight;

import lombok.RequiredArgsConstructor;
import org.springframework.statemachine.StateContext;
import org.springframework.statemachine.guard.Guard;
import org.springframework.stereotype.Component;

@RequiredArgsConstructor
@Component
public class MinimumTimePassedGuard implements Guard<TrafficLightStates, TrafficLightEvents> {

    private static final long MIN_TIME_BETWEEN_TRANSITIONS = 1000 * 2; // 2 Seconds

    private final TimingContext timingContext;

    @Override
    public boolean evaluate(StateContext<TrafficLightStates, TrafficLightEvents> context) {
        long currentTime = System.currentTimeMillis();
        long lastTransitionTime = timingContext.getLastTransitionTime();

        if(lastTransitionTime == 0) {
            return true;
        }

        return (currentTime - lastTransitionTime) >= MIN_TIME_BETWEEN_TRANSITIONS;
    }
}
