package de.w665.pr.statemachine.trafficlight;

import jakarta.annotation.PostConstruct;
import org.jdbi.v3.core.Jdbi;
import org.jdbi.v3.core.mapper.EnumMapper;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;

@Repository
public class StateRepository {

    @Value("${db.address}")
    private String dbAddress;

    @Value("${db.username}")
    private String dbUsername;

    @Value("${db.password}")
    private String dbPassword;

    Jdbi jdbi;

    @PostConstruct
    public void init() {
        jdbi = Jdbi.create(dbAddress, dbUsername, dbPassword);

        // Register enum mapper for TrafficLightStates
        jdbi.registerColumnMapper(TrafficLightStates.class,
                EnumMapper.byName(TrafficLightStates.class));

        // Create the table if it doesn't exist
        jdbi.useHandle(handle -> {
            handle.execute("""
                CREATE TABLE IF NOT EXISTS trafficlightstate (
                    id SERIAL PRIMARY KEY,
                    state VARCHAR(10) NOT NULL,
                    timestamp TIMESTAMP NOT NULL
                )
            """);
        });
    }

    public void saveTrafficLightState(TrafficLightStates trafficLightState) {
        jdbi.useHandle(handle -> {
            handle.createUpdate("INSERT INTO trafficlightstate (state, timestamp) VALUES (:state, :timestamp)")
                    .bind("state", trafficLightState.name())
                    .bind("timestamp", LocalDateTime.now())
                    .execute();
        });
    }
}
