package de.w665.pr.statemachine.trafficlight;

import jakarta.annotation.PostConstruct;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.statemachine.StateMachine;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/traffic")
public class TrafficLightController {

    private int requestCount = 0;

    @Autowired
    private StateMachine<TrafficLightStates, TrafficLightEvents> stateMachine;

    @PostConstruct
    public void init() {
        stateMachine.startReactively().subscribe();
    }

    @GetMapping("/state")
    public String getCurrentState() {
        requestCount++;
        return stateMachine.getState().getId().toString() + " | Total requests: " + requestCount;
    }

    @GetMapping("/next")
    public String triggerNextState() {
        requestCount++;
        stateMachine.sendEvent(TrafficLightEvents.TIMER);
        return "Triggered TIMER event. New state: " + stateMachine.getState().getId() + " | Total requests: " + requestCount;
    }
}
